### 1. Xcode install

https://itunes.apple.com/kr/app/xcode/id497799835?mt=12

If you installed Xcode fully, you should put the below in terminal:

```sh
sudo xcodebuild -license
```

### 2. Homebrew install

Homebrew 설치 시, 터미널 상에 다음과 같이 입력해준다.
```sh
ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
```

bash profile을 다음과 같이 추가해준다.
```sh
vi ~/.profile
export PATH=/usr/local/bin:/usr/local/sbin:$PATH
source ~/.profile
```


### 3. Homebrew GNU GCC Install & Link

For almost HEPtools, one can use just gcc (= clang as default), but in some cases, maybe one needs GNU compilers. 
To install GNU GCC, type:

```sh
brew install gcc
```

then one can use GNU gcc as 'gcc'. If you want to use GNU gcc instead of clang

```sh
ln -s /usr/local/bin/gcc-7 /usr/local/bin/gcc
ln -s /usr/local/bin/g++-7 /usr/local/bin/g++
ln -s /usr/local/bin/gfortran-7 /usr/local/bin/gfortran
```

Then one can use 'gcc' as clang, and 'gcc-7' as GNU compiler.

### 4. Python from Homebrew

```sh
brew install python
```

Setting

```sh
vi ~/.profile
export PATH="/usr/local/opt/python/libexec/bin:$PATH"
source ~/.profile
```

Necessary packages

```sh
python -m pip install numpy scipy matplotlib ipython jupyter
```

### 5. Homebrew-HEP

(http://davidchall.github.io/homebrew-hep/)

```sh
brew tap davidchall/hep
brew info <package>
brew install <package>
```

### 6. CERN ROOT from Homebrew-HEP

```sh
brew tap homebrew/science
brew install root
````

Setting

```sh
vi ~/.profile
#Path For CERN ROOT (from Homebrew-HEP)
alias root='source $ROOTSYS/bin/thisroot.sh; root -l'
export ROOTSYS=/usr/local/Cellar/root/6.10.04
export PATH=$ROOTSYS/bin:$PATH
export LD_LIBRARY_PATH=$ROOTSYS/lib:$PYTHONDIR/lib:$LD_LIBRARY_PATH
export PYTHONPATH=$ROOTSYS/lib/root:$PYTHONPATH
source ~/.profile
```

### 7. LHAPDF from Homebrew-HEP

```sh
brew install lhapdf
```

Package Install

```sh
lhapdf install <pdfname>
lhapdf list --installed
```

Setting

```sh
vi ~/.profile
#Path For LHAPDF (from Homebrew-HEP)
export LHAPDF=/usr/local/Cellar/lhapdf/6.2.0
export LD_LIBRARY_PATH=$LHAPDF/lib:$LD_LIBRARY_PATH
export LHAPDF_DATA_PATH=$LHAPDF/share/LHAPDF
export PYTHONPATH=$PYTHONPATH:$LHAPDF/lib/python2.7/site-packages
source ~/.profile
```

### 8. fastjet from Homebrew-HEP

```sh
brew install fastjet
```

Setting

```sh
vi ~/.profile
#Path For fastjet (from Homebrew-HEP)
export FASTJET=/usr/local/Cellar/fastjet/3.3.0
export LD_LIBRARY_PATH=$FASTJET/lib:$LD_LIBRARY_PATH
export PATH=$FASTJET/include:$PATH
source ~/.profile
```
#### short-example.cc

```cpp
#include "fastjet/ClusterSequence.hh"
#include <iostream>
using namespace fastjet;
using namespace std;

int main () {
  vector<PseudoJet> particles;
  // an event with three particles:   px    py  pz      E
  particles.push_back( PseudoJet(   99.0,  0.1,  0, 100.0) ); 
  particles.push_back( PseudoJet(    4.0, -0.1,  0,   5.0) ); 
  particles.push_back( PseudoJet(  -99.0,    0,  0,  99.0) );

  // choose a jet definition
  double R = 0.7;
  JetDefinition jet_def(antikt_algorithm, R);

  // run the clustering, extract the jets
  ClusterSequence cs(particles, jet_def);
  vector<PseudoJet> jets = sorted_by_pt(cs.inclusive_jets());

  // print out some infos
  cout << "Clustering with " << jet_def.description() << endl;

  // print the jets
  cout <<   "        pt y phi" << endl;
  for (unsigned i = 0; i < jets.size(); i++) {
    cout << "jet " << i << ": "<< jets[i].pt() << " " 
                   << jets[i].rap() << " " << jets[i].phi() << endl;
    vector<PseudoJet> constituents = jets[i].constituents();
    for (unsigned j = 0; j < constituents.size(); j++) {
      cout << "    constituent " << j << "'s pt: " << constituents[j].pt()
           << endl;
    }
  }
} 
```

```sh
g++ short-example.cc -o short-example `$FASTJET/bin/fastjet-config --cxxflags --libs --plugins`
./short-example
```

Example Screen

```sh
#--------------------------------------------------------------------------
#                         FastJet release 3.3.0
#                 M. Cacciari, G.P. Salam and G. Soyez
#     A software package for jet finding and analysis at colliders
#                           http://fastjet.fr
#
# Please cite EPJC72(2012)1896 [arXiv:1111.6097] if you use this package
# for scientific work and optionally PLB641(2006)57 [hep-ph/0512210].
#
# FastJet is provided without warranty under the terms of the GNU GPLv2.
# It uses T. Chan's closest pair algorithm, S. Fortune's Voronoi code
# and 3rd party plugin jet algorithms. See COPYING file for details.
#--------------------------------------------------------------------------
Clustering with Longitudinally invariant anti-kt algorithm with R = 0.7 and E scheme recombination
        pt y phi
jet 0: 103 0 0
    constituent 0's pt: 99.0001
    constituent 1's pt: 4.00125
jet 1: 99 0 3.14159
    constituent 0's pt: 99
```


### 9. PYTHIA8 from Homebrew-HEP

```sh
brew install pythia8
```

Setting

```sh
vi ~/.profile
#Path For PYTHIA8 (from Homebrew-HEP)
export PYTHIA8=/usr/local/Cellar/pythia8/8.223
export LD_LIBRARY_PATH=$PYTHIA8/lib:$LD_LIBRARY_PATH
export PATH=$PYTHIA8/include:$PATH
export PYTHIA8DATA=$PYTHIA8/share/Pythia8/xmldoc
#export PYTHONPATH=$PYTHIA8/lib:$PYTHONPATH
source ~/.profile
```

### 10. madgraph5_amcatnlo (from launchpad, not from Homebrew-HEP)

```sh
brew install gnuplot
brew install ghostscript
```

Setting

```sh
cd $MADGRAPH5/input
vi mg5_configuration.txt
fortran_compiler = gfortran
cpp_compiler = clang++
auto_update = 0 #
run_mode = 2 #
```

```sh
#=========================== MG5 usage 1 =====================================
#Path For madgraph5_amcatnlo (v2.6.0) (from launchpad, not from Homebrew-HEP)
export MADGRAPH5=$TOOLS/MG5_aMC_v2_6_0
alias mg5amc='$MADGRAPH5/bin/mg5_aMC'
#ExRootAnalysis
export ExRoot=$MADGRAPH5/ExRootAnalysis
export LD_LIBRARY_PATH=$ExRoot:$LD_LIBRARY_PATH
#Delphes
export Delphes=$MADGRAPH5/Delphes
export LD_LIBRARY_PATH=$Delphes:$LD_LIBRARY_PATH
#HEPtools
export PATH=$MADGRAPH5/HEPTools/bin:$PATH
export PATH=$MADGRAPH5/HEPTools/include:$PATH
#hepmc
export HEPMC=$MADGRAPH5/HEPTools/hepmc
export LD_LIBRARY_PATH=$HEPMC/lib:$LD_LIBRARY_PATH
export PATH=$HEPMC/include:$PATH
#PYTHIA8
export PYTHIA8=$MADGRAPH5/HEPTools/pythia8
export LD_LIBRARY_PATH=$PYTHIA8/lib:$LD_LIBRARY_PATH
export PATH=$PYTHIA8/include:$PATH
export PYTHIA8DATA=$PYTHIA8/share/Pythia8/xmldoc
#=============================================================================
```

### 11. CalcHEP

```sh
make
./mkWORKdir WORK01
```

Setting

```sh
vi ~/.profile
#CalcHEP
export CALCHEP=$TOOLS/calchep_3.6.27
export LD_LIBRARY_PATH=$CALCHEP/lib:$LD_LIBRARY_PATH
export LHAPDFPATH=$LHAPDF/lib
source ~/.profile
```

If one use MG5(v2.4.X)-PYTHIA6-Delphes3, one can set the bash profile as follows, for instance:

```sh
#=========================== MG5 usage 2 =====================================
#PYTHIA8 (v8.2.26)
export PYTHIA8=$TOOLS/pythia8226
export LD_LIBRARY_PATH=$PYTHIA8/lib:$LD_LIBRARY_PATH
export PYTHIA8DATA=$PYTHIA8/share/Pythia8/xmldoc
export PYTHONPATH=$PYTHIA8/lib:$PYTHONPATH

#MadGraph5 (v2.4.3)
export MADGRAPH5=$TOOLS/MG5_aMC_v2_4_3
alias mg5amc='$MADGRAPH5/bin/mg5_aMC'
#ExRootAnalysis
export ExRoot=$MADGRAPH5/ExRootAnalysis
export LD_LIBRARY_PATH=$ExRoot:$LD_LIBRARY_PATH #Delphes
export Delphes=$MADGRAPH5/Delphes
export LD_LIBRARY_PATH=$Delphes:$LD_LIBRARY_PATH
#Golem95
export GOLEM95=$MADGRAPH5/golem95
export LD_LIBRARY_PATH=$GOLEM95/lib:$LD_LIBRARY_PATH
#HEPtools (ninja, oneloop, etc..)
export PATH=$MADGRAPH5/HEPTools/bin:$PATH
export PATH=$MADGRAPH5/HEPTools/include:$PATH
#=============================================================================
```

### 12. Useful Mathematica packages

```Mathematica
- FeynInstall (FeynArts/FormCalc/LoopTools)

source from http://www.feynarts.de
chmod +x FeynInstall
./FeynInstall

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
- FeynCalc 9 (Symbolic calculation of Dirac matrices and Lorentz tensors)

https://github.com/FeynCalc/feyncalc/wiki/Installation

To do so, you need to download the following 3 files:

https://github.com/FeynCalc/feyncalc/archive/hotfix-stable.zip
https://github.com/FeynCalc/feynarts-mirror/archive/master.zip
https://github.com/FeynCalc/feyncalc/raw/master/install.m

Put these files to the same folder. In the following I assume that it is "/home/vs/Downloads" which will be of course different on your system. 
Then open Mathematica and run
(*Change myPath accordingly! *)
myPath = "/home/vs/Downloads";
$PathToFCArc = FileNameJoin[{myPath,"feyncalc-hotfix-stable.zip"}];
$PathToFAArc = FileNameJoin[{myPath,"feynarts-mirror-master.zip"}];
Get[FileNameJoin[{myPath,"install.m"}]]
InstallFeynCalc[]

This should install FeynCalc and patched FeynArts on your system even when no internet connection is available.

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
- FeynHelpers : Package-X and FIRE5 (Symbolic calculation for amplitudes)

https://github.com/FeynCalc/feynhelpers

Run the following instruction in a Kernel or Notebook session of Mathematica��
Import["https://raw.githubusercontent.com/FeynCalc/feynhelpers/master/install.m"]
InstallFeynHelpers[]
if the above code fails with URLFetch::invhttp: SSL connect error (e.g. on Mathematica 9 under OS X), try
ImportString[URLFetch["https://raw.githubusercontent.com/FeynCalc/feynhelpers/master/install.m"]]
InstallFeynHelpers[]

The automatic installer can also install Package-X and FIRE for you. 
It will offer you this possiblity at the end of the installation process.

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
- xAct (Curvature and tensor symbolic calculations)
Source from http://www.xact.es
just untar and
sudo cp -rf xAct /Users/<user>/Library/Mathematica/Applications/xAct

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
- MSTW2008 PDF (parton distributions)
code and grids from https://mstwpdf.hepforge.org/code/code.html
Available to C++,Fortran,Mathematica

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
```